@@ -73,7 +73,16 @@ fastaTo2bit <- function(origfile, destfile, assembly_accession=NA)
     dna <- readDNAStringSet(origfile)
     if (!is.na(assembly_accession))
         dna <- .sort_and_rename_fasta_sequences(dna, assembly_accession)
+
+    idx <- which(hasAmbiguities(dna, other.than.N=TRUE))
+    if (length(idx) != 0L) {
+        dna[idx] <- replaceAmbiguities(dna[idx])
+        warning(wmsg("the DNA sequences in FASTA file ", origfile, " contain ",
+                     "IUPAC ambiguity letters not supported by ",
+                     "the 2bit format --> replaced them with N's"))
+    }
+
     ## Export file as 2bit.
-    export.2bit(dna, destfile)
+    rtracklayer::export.2bit(dna, destfile)
 }
 
